@@ -1,5 +1,5 @@
 utils::globalVariables(c(
-  "crudes","Contract","Settlement",
+  "crudes","Contract","Settlement","dnorm","pnorm",
   "dflong", "dfwide", "expiry_table", "holidaysOil", "EIAkey",
   "a", "x", "df", "value", "series", "symbol", ".", "price",
   "cmdty", "Date", "expiry", "V1", "yield", "maturity", "contract", "us.df", "cf",
